@@ -16,9 +16,7 @@ pub(crate) mod unit;
 
 ///
 pub(crate) fn make_number(span: Span, value: f64) -> Expr {
-    if cfg!(feature = "debug") {
-        tracing::debug!("Creating a numeric literal");
-    }
+    trace_op!("Creating a numeric literal");
     Expr::Lit(Lit::Num(Number {
         span,
         value,
@@ -94,9 +92,8 @@ impl ModuleItemExt for ModuleItem {
 /// - `!0` for true
 /// - `!1` for false
 pub(crate) fn make_bool(span: Span, value: bool) -> Expr {
-    if cfg!(feature = "debug") {
-        tracing::debug!("Creating a boolean literal");
-    }
+    trace_op!("Creating a boolean literal");
+
     Expr::Unary(UnaryExpr {
         span,
         op: op!("!"),
